@@ -533,7 +533,7 @@ class hgclient(object):
 
     def commit(self, message=None, logfile=None, addremove=False,
                closebranch=False, date=None, user=None, include=None,
-               exclude=None):
+               exclude=None, amend=False):
         """
         Commit changes reported by status into the repository.
 
@@ -545,8 +545,12 @@ class hgclient(object):
         user - record the specified user as committer
         include - include names matching the given patterns
         exclude - exclude names matching the given patterns
+        amend - amend the parent of the working dir
         """
-        if message is None and logfile is None:
+        if amend and message is None and logfile is None:
+            # retrieve current commit message
+            message = self.log('.')[0][5]
+        if message is None and logfile is None and not amend:
             raise ValueError("must provide at least a message or a logfile")
         elif message and logfile:
             raise ValueError("cannot specify both a message and a logfile")
@@ -554,8 +558,7 @@ class hgclient(object):
         # --debug will print the committed cset
         args = cmdbuilder('commit', debug=True, m=message, A=addremove,
                           close_branch=closebranch, d=date, u=user, l=logfile,
-                          I=include, X=exclude)
-
+                          I=include, X=exclude, amend=amend)
         out = self.rawcommand(args)
         rev, node = out.splitlines()[-1].rsplit(':')
         return int(rev.split()[-1]), node
