@@ -18,8 +18,10 @@ class test_resolve(common.basetest):
         self.append('b', 'a')
         rev, self.node3 = self.client.commit('third')
 
-        self.assertRaises(hglib.error.CommandError, self.client.merge, self.node1)
-        self.assertRaises(hglib.error.CommandError, self.client.resolve, all=True)
+        self.assertRaises(hglib.error.CommandError, self.client.merge,
+                          self.node1)
+        self.assertRaises(hglib.error.CommandError,
+                          self.client.resolve, all=True)
 
         self.assertEquals([('U', 'a'), ('U', 'b')],
                           self.client.resolve(listfiles=True))
